@@ -1,6 +1,6 @@
 from __future__ import print_function, division
 
-from sympy.core import S, Basic, Dict, Symbol, Tuple
+from sympy.core import S, Basic, Dict, Symbol, Tuple, sympify
 from sympy.core.compatibility import range, iterable
 from sympy.sets import Set, FiniteSet, EmptySet
 
@@ -722,8 +722,8 @@ class Diagram(Basic):
 
                 for morphism in conclusions_arg:
                     # Check that no new objects appear in conclusions.
-                    if ((objects.contains(morphism.domain) == S.true) and
-                        (objects.contains(morphism.codomain) == S.true)):
+                    if ((sympify(objects.contains(morphism.domain)) is S.true) and
+                        (sympify(objects.contains(morphism.codomain)) is S.true)):
                         # No need to add identities and recurse
                         # composites this time.
                         Diagram._add_morphism_closure(
@@ -920,14 +920,14 @@ class Diagram(Basic):
 
         new_premises = {}
         for morphism, props in self.premises.items():
-            if ((objects.contains(morphism.domain) == S.true) and
-                (objects.contains(morphism.codomain) == S.true)):
+            if ((sympify(objects.contains(morphism.domain)) is S.true) and
+                (sympify(objects.contains(morphism.codomain)) is S.true)):
                 new_premises[morphism] = props
 
         new_conclusions = {}
         for morphism, props in self.conclusions.items():
-            if ((objects.contains(morphism.domain) == S.true) and
-                (objects.contains(morphism.codomain) == S.true)):
+            if ((sympify(objects.contains(morphism.domain)) is S.true) and
+                (sympify(objects.contains(morphism.codomain)) is S.true)):
                 new_conclusions[morphism] = props
 
         return Diagram(new_premises, new_conclusions)
