@@ -31,6 +31,7 @@ Pareto
 QuadraticU
 RaisedCosine
 Rayleigh
+ShiftedGompertz
 StudentT
 Triangular
 Uniform
@@ -84,6 +85,7 @@ __all__ = ['ContinuousRV',
 'RaisedCosine',
 'Rayleigh',
 'StudentT',
+'ShiftedGompertz',
 'Triangular',
 'Uniform',
 'UniformSum',
@@ -2052,6 +2054,67 @@ def Rayleigh(name, sigma):
 
     return rv(name, RayleighDistribution, (sigma, ))
 
+#-------------------------------------------------------------------------------
+# Shifted Gompertz distribution ------------------------------------------------
+
+class ShiftedGompertzDistribution(SingleContinuousDistribution):
+    _argnames = ('b', 'eta')
+
+    set = Interval(0, oo)
+
+    @staticmethod
+    def check(b, eta):
+        _value_check(b > 0, "b must be positive")
+        _value_check(eta > 0, "eta must be positive")
+
+    def pdf(self, x):
+        b, eta = self.b, self.eta
+        return b*exp(-b*x)*exp(-eta*exp(-b*x))*(1+eta*(1-exp(-b*x)))
+
+def ShiftedGompertz(name, b, eta):
+    r"""
+    Create a continuous random variable with a Shifted Gompertz distribution.
+
+    The density of the Shifted Gompertz distribution is given by
+
+    .. math::
+        f(x) := b e^{-b x} e^{-\eta \exp(-b x)} \left[1 + \eta(1 - e^(-bx)) \right]
+
+    with :math: 'x \in [0, \inf)'.
+
+    Parameters
+    ==========
+
+    b: Real number, 'b > 0' a scale
+    eta: Real number, 'eta > 0' a shape
+
+    Returns
+    =======
+
+    A RandomSymbol.
+
+    Examples
+    ========
+    >>> from sympy.stats import ShiftedGompertz, density, E, variance
+    >>> from sympy import Symbol
+
+    >>> b = Symbol("b", positive=True)
+    >>> eta = Symbol("eta", positive=True)
+    >>> x = Symbol("x")
+
+    >>> X = ShiftedGompertz("x", b, eta)
+
+    >>> density(X)(x)
+    b*(eta*(1 - exp(-b*x)) + 1)*exp(-b*x)*exp(-eta*exp(-b*x))
+
+    References
+    ==========
+
+    .. [1] https://en.wikipedia.org/wiki/Shifted_Gompertz_distribution
+
+    """
+    return rv(name, ShiftedGompertzDistribution, (b, eta))
+
 #-------------------------------------------------------------------------------
 # StudentT distribution --------------------------------------------------------
 
