@@ -5,7 +5,6 @@ from itertools import combinations, permutations, product, product as cartes
 import random
 from operator import gt
 
-from sympy.core.decorators import deprecated
 from sympy.core import Basic
 
 # this is the logical location of these functions
@@ -1314,7 +1313,7 @@ def partitions(n, m=None, k=None, size=False):
     ==========
 
     ``m`` : integer (default gives partitions of all sizes)
-        limits number of parts in parition (mnemonic: m, maximum parts)
+        limits number of parts in partition (mnemonic: m, maximum parts)
     ``k`` : integer (default gives partitions number from 1 through n)
         limits the numbers that are kept in the partition (mnemonic: k, keys)
     ``size`` : bool (default False, only partition is returned)
@@ -1340,7 +1339,7 @@ def partitions(n, m=None, k=None, size=False):
     {1: 4, 2: 1}
     {1: 6}
 
-    The maximum number of parts in the partion (the sum of the values in
+    The maximum number of parts in the partition (the sum of the values in
     the returned dict) are limited with m:
 
     >>> for p in partitions(6, m=2):  # doctest: +SKIP
@@ -1753,13 +1752,6 @@ def generate_derangements(perm):
             yield pi
 
 
-@deprecated(
-    useinstead="bracelets", deprecated_since_version="0.7.3")
-def unrestricted_necklace(n, k):
-    """Wrapper to necklaces to return a free (unrestricted) necklace."""
-    return necklaces(n, k, free=True)
-
-
 def necklaces(n, k, free=False):
     """
     A routine to generate necklaces that may (free=True) or may not
